Macros
Structs
- Addr
ToRaw - Doublet
- A
(source, target)pair that identifies a link by its endpoints without an index. - Fuse
- A write-handler wrapper that stops calling the inner handler once it returns
Flow::Break. - Hybrid
- Link
- A link triple
(index, source, target)that represents one node in the doublets graph. - Links
Constants - Point
- A structure representing a single value repeated multiple times.
- Point
Iter - Iterator for Point that yields copies of the stored value.
- Query
- RawTo
Addr
Enums
- Error
- Errors that can be returned by doublets store operations.
- Flow
- Represents the control flow of an operation, similar to
ControlFlow.
Traits
- Doublets
- High-level API for a doublets link store, extending
Linkswith ergonomic helpers. - Doublets
Ext - Extension trait that adds iterator-based access to a
Doubletsstore. - Link
Reference - A composite trait for types that can be used as link identifiers.
- Links
- Low-level, raw slice-based interface for a doublets link store.
- ToQuery
Type Aliases
- Read
Handler - Callback type for read-only link enumeration.
- Write
Handler - Callback type for mutating operations that report
(before, after)link states.