pub struct Fuse<T: LinkReference, H: FnMut(Link<T>, Link<T>) -> Flow> { /* private fields */ }Expand description
A write-handler wrapper that stops calling the inner handler once it returns Flow::Break.
After the first Break, every subsequent call to Fuse::call also returns Break
without invoking the wrapped closure.
Implementations